@@ -1,9 +1,8 @@
-/* $Cambridge: exim/exim-src/src/auths/xtextdecode.c,v 1.5 2009/11/16 19:50:38 nm4 Exp $ */
-
 /*************************************************
 *     Exim - an Internet mail transport agent    *
 *************************************************/
 
+/* Copyright (c) The Exim Maintainers 2022 */
 /* Copyright (c) University of Cambridge 1995 - 2009 */
 /* See the file NOTICE for conditions of use and distribution. */
 
@@ -35,7 +34,7 @@ int
 auth_xtextdecode(uschar *code, uschar **ptr)
 {
 register int x;
-uschar *result = store_get(Ustrlen(code) + 1);
+uschar * result = store_get(Ustrlen(code) + 1, code);
 *ptr = result;
 
 while ((x = (*code++)) != 0)
